from __future__ import annotations

from .FXComposite import FXComposite
from .FXObject import FXObject

#: Split horizontally.
SPLITTER_HORIZONTAL: int = hash("SPLITTER_HORIZONTAL")

#: Split vertically.
SPLITTER_VERTICAL: int = hash("SPLITTER_VERTICAL")

#: Reverse-anchored.
SPLITTER_REVERSED: int = hash("SPLITTER_REVERSED")

#: Track continuous during split.
SPLITTER_TRACKING: int = hash("SPLITTER_TRACKING")

#: Normal splitter style.
SPLITTER_NORMAL: int = hash("SPLITTER_NORMAL")


class FXSplitter(FXComposite):
    """Splitter window is used to interactively repartition two or more subpanes.

    Space may be subdivided horizontally or vertically. When the splitter is itself resized, the right-most
    (bottom-most) child window will be resized unless the splitter window is reversed; if the splitter is
    reversed, the left-most (top-most) child window will be resized instead. The splitter widget sends a
    SEL_CHANGED to its target during the resizing of the panes; at the end of the resize interaction, it
    sends a SEL_COMMAND to signify that the resize operation is complete. Normally, children are resizable
    from 0 upwards; however, if the child in a horizontally oriented splitter has LAYOUT_FILL_X in
    combination with LAYOUT_FIX_WIDTH, it will not be made smaller than its default width, except when the
    child is the last visible widget (or first when the option SPLITTER_REVERSED has been passed to the
    splitter). In a vertically oriented splitter, children with LAYOUT_FILL_Y and LAYOUT_FIX_HEIGHT
    behave analogously. These options only affect interactive resizing.
    """

    def __init__(
        self,
        p: FXComposite,
        tgt: FXObject,
        sel: int,
        opts: int = SPLITTER_NORMAL,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
    ):
        """Construct new splitter widget, which will notify target about size changes.

        Parameters
        ----------
        p : FXComposite

        tgt : FXObject

        sel : int

        opts : int

        x : int

        y : int

        w : int

        h : int
        """

    def getDefaultHeight(self):
        """Get default height.

        Reimplemented from FXComposite.
        """

    def getDefaultWidth(self):
        """Get default width.

        Reimplemented from FXComposite.
        """

    def getSplitterStyle(self):
        """Return current splitter style."""

    def setSplitterStyle(self, style: int):
        """Change splitter style.

        Parameters
        ----------
        style : int
        """



from __future__ import annotations

from .AFXGuiObjectManager import AFXGuiObjectManager
from .FXToolbar import FXToolbar


class AFXToolbarGroup(FXToolbar):
    """This class creates a container to be used for groups in the toolbar.

    It creates a vertical separator after the group. It will use utility methods so the group is correctly
    managed.
    """

    def __init__(self, owner: AFXGuiObjectManager, name: str = "''", title: str = "''"):
        """Constructor.

        Parameters
        ----------
        owner : AFXGuiObjectManager
            Creator of the group.
        name : str
            English toolset name.
        title : str
            Name appearing in the title bar when the group is floating.
        """

    def getDefaultHeight(self):
        """Returns the default height.

        Reimplemented from FXToolbar.
        """

    def getDefaultWidth(self):
        """Returns the default width.

        Reimplemented from FXToolbar.
        """

    def getName(self):
        """Returns the English identifier for the group."""

    def getOwner(self):
        """Returns the creator of the group.

        Reimplemented from FXWindow.
        """

    def getTitle(self):
        """Returns the name appearing in the title bar when the group is floating."""

    def hide(self):
        """Hide this window.

        Reimplemented from FXWindow. Reimplemented in AFXToolbarGroupRender, and AFXToolbarGroupVisibility.
        """

    def isActive(self):
        """Return True if the window is active.

        Reimplemented from FXWindow.
        """

    def layout(self):
        """Calculates layout.

        Reimplemented from FXToolbar.
        """

    def setName(self, name: str):
        """Sets the English identifier for the group.

        Parameters
        ----------
        name : str
        """

    def setTitle(self, title: str):
        """Sets the name appearing in the title bar when the group is floating.

        Parameters
        ----------
        title : str
        """

    def show(self):
        """Show this window.

        Reimplemented from FXWindow. Reimplemented in AFXToolbarGroupRender, and AFXToolbarGroupVisibility.
        """



from __future__ import annotations

from .constants import DEFAULT_SPACING
from .FXComposite import FXComposite
from .FXPacker import FXPacker

#: Fixed number of rows, add columns as needed.
MATRIX_BY_ROWS: int = hash("MATRIX_BY_ROWS")

#: Fixed number of columns, adding rows as needed.
MATRIX_BY_COLUMNS: int = hash("MATRIX_BY_COLUMNS")


class FXMatrix(FXPacker):
    """The Matrix layout manager automatically arranges its child windows in rows and columns.

    If the matrix style is MATRIX_BY_ROWS, then the matrix will have the given number of rows and the
    number of columns grows as more child windows are added; if the matrix style is MATRIX_BY_COLUMNS,
    then the number of columns is fixed and the number of rows grows as more children are added. If all
    children in a row (column) have the LAYOUT_FILL_ROW (LAYOUT_FILL_COLUMN) hint set, then the row
    (column) will be stretchable as the matrix layout manager itself is resized. If more than one row
    (column) is stretchable, the space is apportioned to each stretchable row (column) proportionally.
    Within each cell of the matrix, all other layout hints are observed. For example, a child having
    LAYOUT_CENTER_Y and LAYOUT_FILL_X hints will be centered in the Y-direction, while being stretched
    in the X-direction. Empty cells can be obtained by simply placing a borderless FXFrame widget as a
    space-holder.
    """

    def __init__(
        self,
        p: FXComposite,
        n: int = 1,
        opts: int = MATRIX_BY_ROWS,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = DEFAULT_SPACING,
        pr: int = DEFAULT_SPACING,
        pt: int = DEFAULT_SPACING,
        pb: int = DEFAULT_SPACING,
        hs: int = DEFAULT_SPACING,
        vs: int = DEFAULT_SPACING,
    ):
        """Construct a matrix layout manager with n rows or columns.

        Parameters
        ----------
        p : FXComposite

        n : int

        opts : int

        x : int

        y : int

        w : int

        h : int

        pl : int

        pr : int

        pt : int

        pb : int

        hs : int

        vs : int
        """

    def getDefaultHeight(self):
        """Return default height.

        Reimplemented from FXPacker.
        """

    def getDefaultWidth(self):
        """Return default width.

        Reimplemented from FXPacker.
        """

    def getNumColumns(self):
        """Return the number of columns."""

    def getNumRows(self):
        """Return the number of rows."""

    def setNumColumns(self, nc: int):
        """Change the number of columns.

        Parameters
        ----------
        nc : int
        """

    def setNumRows(self, nr: int):
        """Change the number of rows.

        Parameters
        ----------
        nr : int
        """



from __future__ import annotations

from .constants import DEFAULT_SPACING
from .FXColor import FXColor
from .FXComposite import FXComposite
from .FXFont import FXFont
from .FXObject import FXObject
from .FXPacker import FXPacker

#: Orient label above button.
AFXCOLORBUTTON_VERTICAL: int = hash("AFXCOLORBUTTON_VERTICAL")


class AFXColorButton(FXPacker):
    """This class contains a label that precedes a color well, which allows the user to bring up a color dialog
    box by double clicking.

    When connected to an AFXStringKeyword, this widget will assign the value of the button's current color
    to the keyword in hex format (for example, "FF0000").
    """

    #: ID for color button.
    ID_COLORWELL: int = hash("ID_COLORWELL")

    def __init__(
        self,
        p: FXComposite,
        text: str,
        tgt: FXObject | None = None,
        sel: int = 0,
        opts: int = 0,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = DEFAULT_SPACING,
        pr: int = DEFAULT_SPACING,
        pt: int = DEFAULT_SPACING,
        pb: int = DEFAULT_SPACING,
    ):
        """Constructor.

        Parameters
        ----------
        p : FXComposite
            Parent widget.
        text : str
            Label string.
        tgt : FXObject | None
            Message target.
        sel : int
            Message ID.
        opts : int
            Options and hints.
        x : int
            X coordinate of origin.
        y : int
            Y coordinate of origin.
        w : int
            Width of the widget.
        h : int
            Width of the widget.
        pl : int
            Left padding (margin).
        pr : int
            Right padding (margin).
        pt : int
            Top padding (margin).
        pb : int
            Bottom padding (margin).
        """

    def create(self):
        """Creates the color button widget.

        Reimplemented from FXComposite.
        """

    def disable(self):
        """Disables the color button.

        Reimplemented from FXWindow.
        """

    def enable(self):
        """Enables the color button.

        Reimplemented from FXWindow.
        """

    def getHelpText(self):
        """Returns the status line help text."""

    def getLabelFont(self):
        """Returns the label font."""

    def getLabelText(self):
        """Returns the label string."""

    def getRGBA(self):
        """Returns the color of the button."""

    def getTipText(self):
        """Returns the tool tip message."""

    def setHelpText(self, text: str):
        """Sets the status line help text.

        Parameters
        ----------
        text : str
        """

    def setLabelFont(self, fnt: FXFont):
        """Sets the label font.

        Parameters
        ----------
        fnt : FXFont
        """

    def setLabelText(self, txt: str):
        """Sets the label string.

        Parameters
        ----------
        txt : str
        """

    def setRGBA(self, clr: FXColor):
        """Sets the color of the button.

        Parameters
        ----------
        clr : FXColor
        """

    def setTipText(self, text: str):
        """Sets the tool tip message.

        Parameters
        ----------
        text : str
        """



from __future__ import annotations

import auto_all

from abqpy import run  # noqa

run(cae=True)
auto_all.start_all()

from math import *  # noqa

from .builtin import *  # noqa
from .Canvas.Highlight import *  # noqa
from .Mdb.Mdb import Mdb  # noqa
from .Mdb.MdbCommands import *  # noqa
from .Odb.Odb import Odb  # noqa
from .Session.Session import Session  # noqa
from .UtilityAndView import abaqusConstants  # noqa
from .UtilityAndView.abaqusConstants import OFF, Boolean  # noqa
from .UtilityAndView.BackwardCompatibility import BackwardCompatibility  # noqa
from .UtilityAndView.SymbolicConstant import SymbolicConstant  # noqa
from .UtilityAndView.User import *  # noqa

session = Session()
mdb = Mdb()

backwardCompatibility = BackwardCompatibility()

YES = abaqusConstants.YES
NO = abaqusConstants.NO

auto_all.end_all()



from __future__ import annotations

from .AFXOptionTreeItem import AFXOptionTreeItem
from .constants import DEFAULT_SPACING
from .FXComposite import FXComposite
from .FXObject import FXObject
from .FXScrollWindow import FXScrollWindow


class AFXOptionTreeList(FXScrollWindow):
    """This class provides a scrolled list of groups of options that may be toggled on or off as a group or
    individually."""

    #: ID for the content window.
    ID_CONTENTS: int = hash("ID_CONTENTS")

    def __init__(
        self,
        p: FXComposite,
        nvis: int,
        opts: int = 0,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = DEFAULT_SPACING,
        pr: int = DEFAULT_SPACING,
        pt: int = DEFAULT_SPACING,
        pb: int = DEFAULT_SPACING,
        hs: int = DEFAULT_SPACING,
        vs: int = DEFAULT_SPACING,
    ):
        """Constructor.

        Parameters
        ----------
        p : FXComposite
            Parent widget.
        nvis : int
            Number of visible items of list.
        opts : int
            Options and hints.
        x : int
            X coordinate of origin.
        y : int
            Y coordinate of origin.
        w : int
            Width of the widget.
        h : int
            Height of the widget.
        pl : int
            Left padding.
        pr : int
            Right padding.
        pt : int
            Top padding.
        pb : int
            Bottom padding.
        hs : int
            Horizontal spacing.
        vs : int
            Vertical spacing.
        """

    def addItemFirst(self, text: str, tgt: FXObject | None = None, msg: int = 0):
        """Adds a new item with the given text as the first item of the list.

        Parameters
        ----------
        text : str
            Item text.
        tgt : FXObject | None
            Item target.
        msg : int
            Item selector.
        """

    def addItemLast(self, text: str, tgt: FXObject | None = None, msg: int = 0):
        """Adds a new item with the given text as the last item of the list.

        Parameters
        ----------
        text : str
            Item text.
        tgt : FXObject | None
            Item target.
        msg : int
            Item selector.
        """

    def clearItems(self):
        """Removes all items from the list."""

    def computeItemHeight(self, p: AFXOptionTreeItem | None = None):
        """Computes the item size to be used as a base for default height computation.

        Parameters
        ----------
        p : AFXOptionTreeItem | None
            Item.
        """

    def createItem(self, text: str, tgt: FXObject, msg: int):
        """Creates a new tree item object.

        Parameters
        ----------
        text : str
            Item text.
        tgt : FXObject
            Item target.
        msg : int
            Item selector.
        """

    def getContentHeight(self):
        """Returns the content height.

        Reimplemented from FXScrollWindow.
        """

    def getContents(self):
        """Returns the content window."""

    def getContentWidth(self):
        """Returns the content width.

        Reimplemented from FXScrollWindow.
        """

    def getDefaultHeight(self):
        """Returns the default height.

        Reimplemented from FXScrollArea.
        """

    def getDefaultWidth(self):
        """Returns the default width.

        Reimplemented from FXScrollArea.
        """

    def getFirstItem(self):
        """Returns the first root item."""

    def getHSpacing(self):
        """Returns the horizontal inter-child spacing."""

    def getLastItem(self):
        """Returns the last root item."""

    def getNumItems(self):
        """Returns the number of top-level items."""

    def getNumVisible(self):
        """Returns the number of visible items."""

    def getPadBottom(self):
        """Returns the bottom padding."""

    def getPadLeft(self):
        """Returns the left padding."""

    def getPadRight(self):
        """Returns the right padding."""

    def getPadTop(self):
        """Returns the top padding."""

    def getVSpacing(self):
        """Returns the vertical inter-child spacing."""

    def layout(self):
        """Recalculates layout.

        Reimplemented from FXScrollWindow.
        """

    def moveContents(self, x: int, y: int):
        """Moves contents to the specified position.

        Parameters
        ----------
        x : int
            X location.
        y : int
            Y location
        """

    def removeItem(self, item: AFXOptionTreeItem):
        """Removes the given item from the list. This method does nothing if the given item does not exist.

        Parameters
        ----------
        item : AFXOptionTreeItem
            Item to be removed.
        """

    def setHSpacing(self, hs: int):
        """Sets the horizontal inter-child spacing.

        Parameters
        ----------
        hs : int
            Horizontal spacing.
        """

    def setNumVisible(self, nvis: int):
        """Sets the number of visible items.

        Parameters
        ----------
        nvis : int
            Number of visible items.
        """

    def setPadBottom(self, pb: int):
        """Sets the bottom padding.

        Parameters
        ----------
        pb : int
            Bottom padding.
        """

    def setPadLeft(self, pl: int):
        """Sets the left padding.

        Parameters
        ----------
        pl : int
            Left padding.
        """

    def setPadRight(self, pr: int):
        """Sets the right padding.

        Parameters
        ----------
        pr : int
            Right padding.
        """

    def setPadTop(self, pt: int):
        """Sets the top padding.

        Parameters
        ----------
        pt : int
            Top padding.
        """

    def setVSpacing(self, vs: int):
        """Sets the vertical inter-child spacing.

        Parameters
        ----------
        vs : int
            Vertical spacing.
        """



from __future__ import annotations

from .AFXObjectKeyword import AFXObjectKeyword
from .AFXPickStep import AFXPickStep
from .AFXProcedure import AFXProcedure


class AFXOrderedPickStep(AFXPickStep):
    """This class is used to provide pick steps in GUI procedures."""

    def __init__(
        self, owner: AFXProcedure, keyword: AFXObjectKeyword, prompt: str, entitiesToPick: int, highlightLevel: int = 1
    ):
        """Constructor.

        Parameters
        ----------
        owner : AFXProcedure
            Procedure creating the step.
        keyword : AFXObjectKeyword
            Object kwd containing pick variable. Part of AFXGuiCommand.
        prompt : str
            Step's prompt displayed in prompt area.
        entitiesToPick : int
            Type of entities to pick.
        highlightLevel : int
            Highlight level.
        """

    def onCancel(self):
        """Called when the step is cancelled.

        Reimplemented from AFXPickStep.
        """

    def onExecute(self):
        """Called to execute the steps returned by getFirstStep and getNextStep.

        Reimplemented from AFXPickStep.
        """

    def reset(self):
        """Allows a step to reset any of its data (if needed) when looping.

        Reimplemented from AFXPickStep.
        """



from __future__ import annotations

from .constants import DEFAULT_SPACING
from .FXComposite import FXComposite
from .FXPacker import FXPacker

#: Collapse horizontally to width of current child.
SWITCHER_HCOLLAPSE: int = hash("SWITCHER_HCOLLAPSE")

#: Collapse vertically to height of current child.
SWITCHER_VCOLLAPSE: int = hash("SWITCHER_VCOLLAPSE")


class FXSwitcher(FXPacker):
    """The Switcher layout manager automatically arranges its child windows such that one of them is placed on
    top; all other child windows are hidden.

    Switcher provides a convenient method to conserve screen real-estate by arranging several GUI panels to
    appear in the same space, depending on context. Switcher ignores all layout hints from its children:-
    all children are stretched according to the switcher layout managers own size. When the
    SWITCHER_HCOLLAPSE or SWITCHER_VCOLLAPSE options are used, Switcher's default size is based on the
    width or height of the current child, instead of the maximum width or height of all of the children.
    """

    #: ID for the 1st child.
    ID_OPEN_FIRST: int = hash("ID_OPEN_FIRST")

    #: ID for the 2nd child.
    ID_OPEN_SECOND: int = hash("ID_OPEN_SECOND")

    #: ID for the 3rd child.
    ID_OPEN_THIRD: int = hash("ID_OPEN_THIRD")

    #: ID for the 4th child.
    ID_OPEN_FOURTH: int = hash("ID_OPEN_FOURTH")

    #: ID for the 5th child.
    ID_OPEN_FIFTH: int = hash("ID_OPEN_FIFTH")

    #: ID for the 6th child.
    ID_OPEN_SIXTH: int = hash("ID_OPEN_SIXTH")

    #: ID for the 7th child.
    ID_OPEN_SEVENTH: int = hash("ID_OPEN_SEVENTH")

    #: ID for the 8th child.
    ID_OPEN_EIGHTH: int = hash("ID_OPEN_EIGHTH")

    #: ID for the 9th child.
    ID_OPEN_NINETH: int = hash("ID_OPEN_NINETH")

    #: ID for the 10th child.
    ID_OPEN_TENTH: int = hash("ID_OPEN_TENTH")

    def __init__(
        self,
        p: FXComposite,
        opts: int = 0,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = DEFAULT_SPACING,
        pr: int = DEFAULT_SPACING,
        pt: int = DEFAULT_SPACING,
        pb: int = DEFAULT_SPACING,
    ):
        """Construct a switcher layout manager.

        Parameters
        ----------
        p : FXComposite

        opts : int

        x : int

        y : int

        w : int

        h : int

        pl : int

        pr : int

        pt : int

        pb : int
        """

    def getCurrent(self):
        """Return the index of the child window currently on top."""

    def getDefaultHeight(self):
        """Return default height.

        Reimplemented from FXPacker.
        """

    def getDefaultWidth(self):
        """Return default width.

        Reimplemented from FXPacker.
        """

    def setCurrent(self, index: int, notify: bool = False):
        """Bring the child window at index to the top.

        Parameters
        ----------
        index : int

        notify : bool
        """



from __future__ import annotations

from .FXButton import FXButton
from .FXComposite import FXComposite
from .FXIcon import FXIcon
from .FXObject import FXObject


class AFXToolButton(FXButton):
    """This class contains a button for use in the tool bar or the toolbox."""

    def __init__(
        self,
        p: FXComposite,
        label: str,
        icon: FXIcon | None = None,
        tgt: FXObject | None = None,
        sel: int = 0,
        asToggle: bool = True,
    ):
        """Constructor.

        Parameters
        ----------
        p : FXComposite
            Parent widget.
        label : str
            Label for the button.
        icon : FXIcon | None
            Icon for the button.
        tgt : FXObject | None
            Message target.
        sel : int
            Message ID.
        asToggle : bool
            Allow toggle off behavior.
        """



from abqpy.decorators import abaqus_class_doc

from ..UtilityAndView.abaqusConstants import MODEL, SymbolicConstant


@abaqus_class_doc
class StopCondition:
    """The StopCondition object is the abstract base type for other StopCondition objects. The StopCondition
    object has no explicit constructor. The methods and members of the StopCondition object are common to all
    objects derived from StopCondition.

    .. note::
        This object can be accessed by::

            import optimization
            mdb.models[name].optimizationTasks[name].stopConditions[name]
    """

    #: A String specifying the stop condition repository key.
    name: str = ""

    #: The SymbolicConstant MODEL or a Region object specifying the region to which the stop
    #: condition is applied. The default value is MODEL.
    region: SymbolicConstant = MODEL



"""
Compression Output Script
-------------------------

A script to get the output of the compression model.

The model script of this example can be found :doc:`here <compression>`.
"""

import numpy as np

import visualization
from abaqus import *
from abaqusConstants import *
from driverUtils import *

executeOnCaeStartup()

# Open output database
odb = session.openOdb("Job-1.odb")

# Show the output database in viewport
session.viewports["Viewport: 1"].setValues(displayedObject=odb)

# Extract output data
dataList = session.xyDataListFromField(
    odb=odb, outputPosition=NODAL, variable=(("U", NODAL, ((COMPONENT, "U3"),)),), nodeSets=("INSTANCE.SET-TOP",)
)

data = np.array(dataList[0])
np.savetxt("data.csv", data, header="time,U3", delimiter=",", comments="")



from __future__ import annotations

from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ....UtilityAndView.abaqusConstants import EXPONENTIAL, OFF, Boolean
from ....UtilityAndView.abaqusConstants import abaqusConstants as C
from .ClayHardening import ClayHardening


@abaqus_class_doc
class ClayPlasticity:
    r"""The ClayPlasticity object specifies the extended Cam-clay plasticity model.

    .. note::
        This object can be accessed by::

            import material
            mdb.models[name].materials[name].clayPlasticity
            import odbMaterial
            session.odbs[name].materials[name].clayPlasticity

        The table data for this object are:

        - If **hardening** = EXPONENTIAL, the table data specify the following:

            - Logarithmic plastic bulk modulus, :math:`\lambda` (dimensionless).
            - Stress ratio at critical state, :math:`M`.
            - The initial yield surface size, :math:`a_{0}`.
            - :math:`\beta`, the parameter defining the size of the yield surface on the "wet" side of critical state.
            - :math:`K`, the ratio of the flow stress in triaxial tension to the flow stress in triaxial
              compression. :math:`0.778 \leq K \leq 1.0`. If the default value of :math:`0.0` is accepted, a
              value of :math:`1.0` is assumed.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **hardening** = TABULAR, the table data specify the following:

            - Stress ratio at critical state, :math:`M`
            - The initial volumetric plastic strain, :math:`\left.\varepsilon_{\mathrm{vol}}^{p l}\right|_{0}`,
              corresponding to :math:`\left.p_{c}\right|_{0}` according to the ClayHardening definition.
            - :math:`\beta`, the parameter defining the size of the yield surface on the "wet" side of critical state.
            - :math:`K`, the ratio of the flow stress in triaxial tension to the flow stress in triaxial compression.
              :math:`0.778 \leq K \leq 1.0`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.

        The corresponding analysis keywords are:

        - CLAY PLASTICITY
    """

    #: A ClayHardening object.
    clayHardening: ClayHardening = ClayHardening(((),))

    @abaqus_method_doc
    def __init__(
        self,
        table: tuple,
        intercept: float | None = None,
        hardening: Literal[C.EXPONENTIAL, C.TABULAR] = EXPONENTIAL,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates a ClayPlasticity object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].ClayPlasticity
                session.odbs[name].materials[name].ClayPlasticity

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        intercept
            None or a Float specifying :math:`e_1`, the intercept of the virgin consolidation line with the
            void ratio axis in a plot of void ratio versus the logarithm of pressure stress. The
            default value is None.This argument is valid only if **hardening** = EXPONENTIAL.
        hardening
            A SymbolicConstant specifying the type of hardening/softening definition. Possible
            values are EXPONENTIAL and TABULAR. The default value is EXPONENTIAL.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        ClayPlasticity
            A ClayPlasticity object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the ClayPlasticity object.

        Raises
        ------
        RangeError
        """
        ...



from __future__ import annotations

import auto_all

from abqpy import run

run(cae=False)
auto_all.start_all()

from math import *  # noqa

from abaqus.Odb.Odb import Odb  # noqa
from abaqus.Odb.OdbCommands import (  # noqa
    AnalyticSurfaceProfile,
    isUpgradeRequiredForOdb,
    maxEnvelope,
    minEnvelope,
    openOdb,
    upgradeOdb,
)
from abaqus.UtilityAndView.BackwardCompatibility import BackwardCompatibility  # noqa
from abaqusConstants import *  # noqa

backwardCompatibility = BackwardCompatibility()

auto_all.end_all()



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..Region.Region import Region
from .GeometricRestriction import GeometricRestriction


@abaqus_class_doc
class BeadPenetrationCheck(GeometricRestriction):
    """The BeadPenetrationCheck object defines a penetration check geometric restriction. The
    BeadPenetrationCheck object is derived from the GeometricRestriction object.

    .. note::
        This object can be accessed by::

            import optimization
            mdb.models[name].optimizationTasks[name].geometricRestrictions[name]
    """

    #: A String specifying the geometric restriction repository key.
    name: str

    #: A Region object specifying the penetration check region.
    beadPenetrationCheckRegion: Region

    #: A Region object specifying the region to which the geometric restriction is applied.
    region: Region

    @abaqus_method_doc
    def __init__(self, name: str, beadPenetrationCheckRegion: Region, region: Region):
        """This method creates a BeadPenetrationCheck object.

        .. note::
            This function can be accessed by::

                mdb.models[name].optimizationTasks[name].BeadPenetrationCheck

        Parameters
        ----------
        name
            A String specifying the geometric restriction repository key.
        beadPenetrationCheckRegion
            A Region object specifying the penetration check region.
        region
            A Region object specifying the region to which the geometric restriction is applied.

        Returns
        -------
        BeadPenetrationCheck
            A BeadPenetrationCheck object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the BeadPenetrationCheck object."""
        ...



from __future__ import annotations

from .constants import DEFAULT_PAD
from .FXColor import FXColor
from .FXComposite import FXComposite
from .FXFrame import FXFrame
from .FXObject import FXObject

#: No arrow.
ARROW_NONE: int = hash("ARROW_NONE")

#: Arrow points up.
ARROW_UP: int = hash("ARROW_UP")

#: Arrow points down.
ARROW_DOWN: int = hash("ARROW_DOWN")

#: Arrow points left.
ARROW_LEFT: int = hash("ARROW_LEFT")

#: Arrow points right.
ARROW_RIGHT: int = hash("ARROW_RIGHT")

#: Button repeats if held down.
ARROW_REPEAT: int = hash("ARROW_REPEAT")

#: Automatically gray out when not updated.
ARROW_AUTOGRAY: int = hash("ARROW_AUTOGRAY")

#: Automatically hide button when not updated.
ARROW_AUTOHIDE: int = hash("ARROW_AUTOHIDE")

#: Button is toolbar-style.
ARROW_TOOLBAR: int = hash("ARROW_TOOLBAR")

#: Button is spinner-style.
ARROW_SPINNER: int = hash("ARROW_SPINNER")

#: Normal arrow button.
ARROW_NORMAL: int = hash("ARROW_NORMAL")


class FXArrowButton(FXFrame):
    """Button with an arrow; the arrow can point in any direction.

    When clicked, the arrow button sends a SEL_COMMAND to its target. When ARROW_REPEAT is passed, the
    arrow button sends a SEL_COMMAND repeatedly while the button is pressed.
    """

    def __init__(
        self,
        p: FXComposite,
        tgt: FXObject | None = None,
        sel: int = 0,
        opts: int = ARROW_NORMAL,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = DEFAULT_PAD,
        pr: int = DEFAULT_PAD,
        pt: int = DEFAULT_PAD,
        pb: int = DEFAULT_PAD,
    ):
        """Construct arrow button.

        Parameters
        ----------
        p : FXComposite

        tgt : FXObject | None

        sel : int

        opts : int

        x : int

        y : int

        w : int

        h : int

        pl : int

        pr : int

        pt : int

        pb : int
        """

    def canFocus(self):
        """Returns True because a button can receive focus.

        Reimplemented from FXWindow.
        """

    def disable(self):
        """Disable the button.

        Reimplemented from FXWindow.
        """

    def enable(self):
        """Enable the button.

        Reimplemented from FXWindow.
        """

    def getArrowColor(self):
        """Get the fill color for the arrow."""

    def getArrowSize(self):
        """Get the default arrow size."""

    def getArrowStyle(self):
        """Get the arrow style flags."""

    def getDefaultHeight(self):
        """Get default height.

        Reimplemented from FXFrame.
        """

    def getDefaultWidth(self):
        """Get default width.

        Reimplemented from FXFrame.
        """

    def getJustify(self):
        """Get the current justification mode."""

    def getState(self):
        """Get the button state (where True means the button is down)."""

    def getTipText(self):
        """Get tool tip message for this arrow button."""

    def setArrowColor(self, clr: FXColor):
        """Set the fill color for the arrow.

        Parameters
        ----------
        clr : FXColor
        """

    def setArrowSize(self, size: int):
        """Set the default arrow size.

        Parameters
        ----------
        size : int
        """

    def setArrowStyle(self, style: int):
        """Set the arrow style flags.

        Parameters
        ----------
        style : int
        """

    def setJustify(self, mode: int):
        """Set the current justification mode.

        Parameters
        ----------
        mode : int
        """

    def setState(self, s: bool):
        """Set the button state (where True means the button is down).

        Parameters
        ----------
        s : bool
        """

    def setTipText(self, text: str):
        """Set tool tip message for this arrow button.

        Parameters
        ----------
        text : str
        """
